import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';

import 'package:random/provider/data.dart';
import 'package:random/activities/ActivityDemoPage.dart';
import 'package:random/activities/ActivityGraphPage.dart';
import 'package:random/screens/home.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  SystemChrome.setPreferredOrientations([DeviceOrientation.portraitUp])
      .then((value) => runApp(MyApp()));
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (BuildContext context) => Data(),
      child: Consumer<Data>(builder: (context, data, child) {
        return MaterialApp(
          title: 'Random application - testing stuff...',
          theme: ThemeData(
            primarySwatch: Colors.blue,
          ),
          home: Home(),
          onGenerateRoute: (settings) {
            switch (settings.name) {
              case ActivityDemoPage.route:
                {
                  return MaterialPageRoute(
                    builder: (context) => ActivityDemoPage(),
                  );
                }
              case ActivityGraphPage.route:
                {
                  return MaterialPageRoute(
                    builder: (context) => ActivityGraphPage(),
                  );
                }

              default:
                {
                  print("Unknown menu entry: " + settings.name.toString());
                }
                break;
            }

            return null;
          },
        );
      }),
    );
  }
}
